@@ -14,17 +14,17 @@ sigu <- var1$sigu
 {
 if(restrict1=="full") {
 
-VARmat = VAR.Rmat(p,k,restrict0)
+VARmat = VAR.Rmat(p,k,restrict0,type)
 Rmat2 = VARmat$Rmat; rmat2 = VARmat$rvec
 sigu1 = var1$sigu *((n-p)-ncol(b))/(n-p); nor=nrow(restrict0)
 sigu2=VAR.Rtem(x,p,sigu,Rmat2,rmat2,type)$sigu
 df3=ncol(var1$coef)}
 else {
 
-VARmat = VAR.Rmat(p,k,restrict1)
+VARmat = VAR.Rmat(p,k,restrict1,type)
 Rmat1 = VARmat$Rmat; rmat1 = VARmat$rvec
 
-VARmat = VAR.Rmat(p,k,restrict0)
+VARmat = VAR.Rmat(p,k,restrict0,type)
 Rmat2 = VARmat$Rmat; rmat2 = VARmat$rvec
 
 sigu2=VAR.Rtem(x,p,sigu,Rmat1,rmat1,type)$sigu 
